SQLObject Links — SQLObject 3.9.1 documentation

# SQLObject Links

Contents

- SQLObject Links

  - Articles and Documentation

  - Open Source Projects

If you have a link you’d like added to this page, please submit a pull requests at GitHub or a bug report with the link and title at bug tracker.

## Articles and Documentation

- Connecting databases to Python with SQLObject; an article at DeveloperWorks.

- DB migration using sqlobject-admin how-to.

- Using raw SQL with SQLObject and keeping the object-y goodness.

- Example of using SQLObject with web.py under mod_wsgi.

## Open Source Projects

- Catwalk is a web-based SQLObject browser and object editor (included in TurboGears 1.0).

- Ultra Gleeper, a Recommendation Engine for Web Pages.

- Guten; an application for browsing, reading, and managing books from Project Gutenberg.